==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/networking/v1/NetworkPolicyStatus.scala <==
package io.k8s.api.networking.v1

import dev.hnaderi.k8s.utils._

/** NetworkPolicyStatus describe the current state of the NetworkPolicy. */
final case class NetworkPolicyStatus(
  conditions : Option[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]] = None
) {

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : NetworkPolicyStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.apimachinery.pkg.apis.meta.v1.Condition*) : NetworkPolicyStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition] => Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : NetworkPolicyStatus = copy(conditions = conditions.map(f))
}

object NetworkPolicyStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.networking.v1.NetworkPolicyStatus, T] = new Encoder[io.k8s.api.networking.v1.NetworkPolicyStatus, T] {
        def apply(o: io.k8s.api.networking.v1.NetworkPolicyStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, NetworkPolicyStatus] = new Decoder[T, NetworkPolicyStatus] {
      def apply(t: T): Either[String, NetworkPolicyStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]]("conditions")
      } yield NetworkPolicyStatus (
          conditions = conditions
        )
    }
}

==> scala-k8s-objects_sjs1_2.12-0.13.0-sources.jar: io/k8s/api/networking/v1/NetworkPolicyStatus.scala <==
package io.k8s.api.networking.v1

import dev.hnaderi.k8s.utils._

/** NetworkPolicyStatus describes the current state of the NetworkPolicy. */
final case class NetworkPolicyStatus(
  conditions : Option[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]] = None
) {

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : NetworkPolicyStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.apimachinery.pkg.apis.meta.v1.Condition*) : NetworkPolicyStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition] => Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]) : NetworkPolicyStatus = copy(conditions = conditions.map(f))
}

object NetworkPolicyStatus {

    implicit val encoder : Encoder[io.k8s.api.networking.v1.NetworkPolicyStatus] = new Encoder[io.k8s.api.networking.v1.NetworkPolicyStatus] {
        def apply[T : Builder](o: io.k8s.api.networking.v1.NetworkPolicyStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .build
        }
    }

    implicit val decoder: Decoder[NetworkPolicyStatus] = new Decoder[NetworkPolicyStatus] {
      def apply[T : Reader](t: T): Either[String, NetworkPolicyStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.apimachinery.pkg.apis.meta.v1.Condition]]("conditions")
      } yield NetworkPolicyStatus (
          conditions = conditions
        )
    }
}
